@@ -1,4 +1,5 @@
 from datetime import timedelta
+from django.core.cache import cache
 from dimagi.utils.couch.delete import delete
 from dimagi.utils.couch.safe_index import safe_index
 from couchdbkit.ext.django.schema import DateTimeProperty, DocumentSchema
@@ -43,3 +44,16 @@ class LooselyEqualDocumentSchema(DocumentSchema):
     def __hash__(self):
         return hash(json.dumps(self._doc, sort_keys=True))
 
+def get_cached_property(couch_cls, obj_id, prop_name, expiry=12*60*60):
+    """
+        A function that returns a property of any couch object. If it doesn't find the property in memcached, it does
+        the couch query to pull the object and grabs the property. Then it caches the retrieved property.
+        Note: The property needs to be pickleable
+    """
+    cache_str = "{0}:{1}:{2}".format(couch_cls.__name__, obj_id, prop_name)
+    ret = cache.get(cache_str)
+    if not ret:
+        obj = couch_cls.get(obj_id)
+        ret = getattr(obj, prop_name)
+        cache.set(cache_str, ret, expiry)
+    return ret
